#
# spec file for package opensurge
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           opensurge
Version:        0.6.0.3
Release:        2.5
Summary:        Game based on Sonic the Hedgehog Universe
License:        Apache-2.0 AND GPL-3.0-or-later AND LGPL-2.1-or-later AND CC-BY-3.0 AND OFL-1.1 AND MIT
Group:          Amusements/Games/Action/Arcade
URL:            https://opensurge2d.org/
Source0:        https://github.com/alemart/opensurge/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  desktop-file-utils
BuildRequires:  fdupes
%if 0%{?suse_version} <= 1500
BuildRequires:  gcc10-c++
%else
BuildRequires:  gcc-c++
%endif
BuildRequires:  update-desktop-files
BuildRequires:  cmake(OpenAL)
BuildRequires:  pkgconfig(allegro-5)
BuildRequires:  pkgconfig(allegro_acodec-5)
BuildRequires:  pkgconfig(allegro_audio-5)
BuildRequires:  pkgconfig(allegro_dialog-5)
BuildRequires:  pkgconfig(allegro_font-5)
BuildRequires:  pkgconfig(allegro_image-5)
BuildRequires:  pkgconfig(allegro_memfile-5)
BuildRequires:  pkgconfig(allegro_primitives-5)
BuildRequires:  pkgconfig(allegro_ttf-5)
BuildRequires:  pkgconfig(surgescript) >= 0.5.6

%description
Open Surge is a retro-style 2D sidescroller inspired by old-school
games. The characters named Surge, Neon and Charge are to save the
world from the evil Gimacian the Dark.

%prep
%autosetup

%build
%if 0%{?suse_version} <= 1500
export CC=gcc-10
export CXX=g++-10
%endif

%cmake \
    -DGAME_BINDIR="%{_bindir}" \
    -DGAME_DATADIR="%{_datadir}/%{name}"
%cmake_build

%install
%cmake_install

%suse_update_desktop_file %{name}
%fdupes %{buildroot}%{_prefix}

# remove docs
rm -fv %{buildroot}%{_datadir}/%{name}/{CHANGES.md,LICENSE,README.md}
rm -rfv %{buildroot}%{_datadir}/%{name}/licenses

%files
%license licenses/*
%doc CHANGES.md README.md
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/metainfo/%{name}.appdata.xml
%{_datadir}/pixmaps/%{name}.png
%{_datadir}/%{name}

%changelog
* Tue Nov  8 2022 Carsten Ziepke <kieltux@gmail.com>
- Fix building for openSUSE Leap: using gcc10
* Fri Sep 30 2022 Martin Hauke <mardnh@gmx.de>
- Update to version 0.6.0.3
  * Tweaks to the level design, to the default controls and to
    the build system.
  * Changed the way the engine handles analog sticks.
* Thu Sep 15 2022 Martin Hauke <mardnh@gmx.de>
- Update to version 0.6.0.2
  * Adjusted gimmicks: Water Bubbles, Spikes.
  * Made tweaks to the level design, to the title screen and to
    the build script.
  * Changed the parser used on the stage select.
  * Added support for loading quests via developer mode.
  * Removed the quest selection screen.
- Update to version 0.6.0.1
  * Updated the default mapping for gamepads.
  * Adjusted the "Walk on Water" gimmick.
  * Optimized the creation and the rendering of brick particles.
  * Made tweaks to the level design.
- Update to version 0.6.0
  * Renamed the game to Surge the Rabbit.
  * Improved the pixel art style of the game.
  * Created a new Waterworks Zone.
  * New gimmicks: Conveyor Belts, Walk on Water, Power Pluggy.
  * New title screen and new title card animation.
  * New translations: Italian, Esperanto.
  * Introduced language extensions (languages/extends/ folder).
  * Introduced support for transitions between animations.
  * Introduced the concepts of action spot and sprite anchor.
  * Improvements to the SurgeScript API.
  * Improved several core scripts.
  * Added support for compound ${EXPRESSIONS} when evaluating text.
  * Changed the physics.
  * Added support for D-pad input on Xbox controllers.
  * Removed legacy Allegro 4 code.
  * Bugfixes and general improvements.
* Sat May  1 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 0.5.2.1:
  * Include LMMS source files (1up, speed, drowning, gameover)
  * Player: reduce jump_lock_timer after charging
  * Small fixes & adjustments
* Mon Mar 22 2021 Jan Engelhardt <jengelh@inai.de>
- Trim metadata and imperatives from description.
* Fri Mar 12 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 0.5.2
  * Improved joystick support
  * New translations: Polish, Russian
  * New musics
  * Updated the Giant Wolf Boss
  * Added new little animals
  * Increased the drowning time to 12 seconds
  * Updated the turbo/invincibility time to 20 seconds
  * Improved the springs: they now behave as expected when the player
    is running on the walls or on the ceiling
  * Level Editor: users can now create levels in fullscreen mode
  * Level Editor: users can now display collision gizmos by pressing a key
  * Level Editor: the interface has been translated into multiple languages
  * Fix: the engine will pause the SurgeScript VM when the game is paused
  * Fix: consistent physics in slow computers
  * Fix: the player can be smashed by solid moving platforms
  * Increased the maximum supported image size to 4096x4096 pixels
  * Bugfixes and general improvements
- Dropped legacy dependencies
- Fixed confusing description
* Fri Apr 24 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.5.1.2 (see CHANGES.md)
- Drop opensurge-gcc5.patch (no longer useful)
- Drop opensurge.desktop (use upstream one)
- Drop opensurge.sh wrapper (apparently no longer useful)
- Do not use system fonts (only some are available and the
  package is much larger, therefore nullifying any size
  advantage)
- Spec cleanup
* Sun Dec 27 2015 rpm@fthiessen.de
- Added opensurge-gcc5.patch to fix build with gcc5, needed for
  openSUSE > 13.2
* Wed Oct 15 2014 nemysis@gmx.ch
- Use %%{_libexecdir} instead of {_datadir}
- Add sed, fix path
- Change opensurge.sh
* Mon Oct  6 2014 nemysis@gmx.ch
- Add BuildRequires for dejavu-fonts
- Replace bundled font with a symlink to an identical system font
* Sun Oct  5 2014 nemysis@gmx.ch
- Change Desktop entry file
- Change %%fdupes
* Tue Sep 30 2014 nemysis@gmx.ch
- Divide mods to new RPM opensurge-mods
- Remove opensurge-0.1.99_svn765-licenses_OpenALSoft.txt.patch
- Fix Usage, add wrapper opensurge.sh
- Use %%{name}.desktop instead of Desktop Entry in spec
- Add BuildRequires for libdumb-devel (Error loading libdumb.so)
- Add Requires: %%{name}-mods
- Change description
- Remove not needed mkdir -p
* Sat Sep 13 2014 nemysis@gmx.ch
- Simplify installation handling
* Tue Sep  9 2014 nemysis@gmx.ch
- Used many from mine FreeBSD port games/opensurge
- Fixed "Please submit bugfixes" and added for Open Surge
- Add more Levels from Open Surge Forum, opensurge-mods-20140321.tar.gz
- Add opensurge-0.1.99_svn765-licenses_OpenALSoft.txt.patch,
  correct FSF Address
- Use in spec "cmake .", because not build with %%%%cmake macros
  CMake Error: The source directory "/home/nemysis/rpmbuild/BUILD/opensurge-svn/build"
  does not appear to contain CMakeLists.txt
- Initial package creation
